aboutsummaryrefslogtreecommitdiff
path: root/bpkg/package-skeleton.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bpkg/package-skeleton.hxx')
-rw-r--r--bpkg/package-skeleton.hxx14
1 files changed, 10 insertions, 4 deletions
diff --git a/bpkg/package-skeleton.hxx b/bpkg/package-skeleton.hxx
index 0fc371d..d7cafe9 100644
--- a/bpkg/package-skeleton.hxx
+++ b/bpkg/package-skeleton.hxx
@@ -73,14 +73,13 @@ namespace bpkg
// The following functions should be called in the following sequence
// (* -- zero or more, ? -- zero or one):
//
- // * reload_defaults()
- // * verify_sensible()
+ // * reload_defaults() | verify_sensible()
// ? dependent_config()
- // * evaluate_enable() | evaluate_reflect()
+ // * evaluate_*()
// collect_config()
//
// Note that a copy of the skeleton is expected to continue with the
// sequence rather than starting from scratch.
//
public:
// Reload the default values and type information for configuration
@@ -136,6 +135,13 @@ namespace bpkg
evaluate_require (const dependency_configurations&,
const string&, size_t depends_index);
+ // Reset the skeleton to the start of the call sequence.
+ //
+ // Note that this function cannot be called after collect_config().
+ //
+ void
+ reset ();
+
// Return the accumulated configuration variables (first) and project
// configuration variable sources (second). Note that the arrays are not
// necessarily parallel (config_vars may contain non-project variables).
@@ -73,14 +73,13 @@ namespace bpkg
//
// Note that a copy of the skeleton is expected to continue with the
- // sequence rather than starting from scratch.
+ // sequence rather than starting from scratch, unless reset() is called.
//
public: